@@ -1,10 +1,13 @@
 #![allow(non_snake_case)]
 //! All sorts of geometrical functions, constants and procedures
-use std::ops::{Mul, Neg};
 
-use crate::point::{Point, Vec2DWorld};
+use crate::point::{Point, Vec2D, Vec2DWorld};
 use crate::transform::Transform;
 
+mod angle;
+
+pub use angle::Angle;
+
 /// How many points will be used to approximate the bezier curve for the purpose
 /// of erasing a shape.
 ///
@@ -13,62 +16,6 @@ use crate::transform::Transform;
 /// Too many will impact performance.
 const BEZIER_PARTS: usize = 50;
 
-/// Stores the angle in radians internally
-#[derive(Copy, Clone, Debug, Default, PartialEq)]
-pub struct Angle(f64);
-
-impl Angle {
-    pub fn is_zero(self) -> bool {
-        self.0 == 0.0
-    }
-
-    pub fn degrees(self) -> f64 {
-        self.0.to_degrees()
-    }
-
-    pub fn radians(self) -> f64 {
-        self.0
-    }
-
-    pub fn from_radians(radians: f64) -> Angle {
-        Angle(radians)
-    }
-
-    pub fn from_degrees(degrees: f64) -> Angle {
-        Angle(degrees.to_radians())
-    }
-
-    pub fn between<P: Point>(a: P, b: P) -> Angle {
-        if a == b {
-            return Angle::from_radians(0.0);
-        }
-
-        let angle = (dot(a, b)/(a.magnitude() * b.magnitude())).acos();
-
-        Self::from_radians(if a.x() * b.y() - a.y() * b.x() < 0.0 {
-            -angle
-        } else {
-            angle
-        })
-    }
-}
-
-impl Mul<f64> for Angle {
-    type Output = Self;
-
-    fn mul(self, s: f64) -> Angle {
-        Angle::from_radians(self.radians() *  s)
-    }
-}
-
-impl Neg for Angle {
-    type Output = Self;
-
-    fn neg(self) -> Self {
-        Angle(-self.0)
-    }
-}
-
 fn dot<P: Point>(a: P, b: P) -> f64 {
     a.x() * b.x() + a.y() * b.y()
 }
@@ -427,6 +374,42 @@ pub fn distance_from_point_to_ellipse<P: Point>(point: P, ellipse: Ellipse<P>) -
     distance
 }
 
+/// Given the three points that define a rombus in some space, return the
+/// matrix that transform its space into one where that very rombus is rectangle
+/// in the first quadrant.
+///
+/// The three points are considered to be laid out like this, modulo some
+/// rotations, scales and mirrors:
+///
+/// ```text
+///                 p2
+///                 ^
+///                /
+///               /
+/// origin ---> p1
+/// ```
+///
+/// so that when the space is transformed they will ve the two unit vectors that
+/// define the space î and ĵ
+pub fn rombus_to_rectangle(origin: Vec2D, p1: Vec2D, p2: Vec2D) -> Transform {
+    // first vector. In the final transformed space this will point to the
+    // positive X axis and be perfectly horizontal
+    let a = p1 - origin;
+
+    let t = Transform::new_translate(-origin).rotate(-a.angle());
+
+    // Ensure that the second point is in the first quadrant by reflecting along
+    // the X axis only of the Y coordinate of a transformed point is negative.
+    let t = if t.apply(p2).y() < 0.0 { t.scale_y(-1.0) } else { t };
+
+    let p1p = t.apply(p1);
+    let p2p = t.apply(p2);
+    let bp = p2p - p1p;
+    let shear_factor = bp.x() / bp.y();
+
+    t.shear_x(-shear_factor)
+}
+
 #[cfg(test)]
 mod tests {
     use crate::point::{Vec2DScreen, Vec2D};
@@ -620,4 +603,19 @@ mod tests {
             );
         }
     }
+
+    #[test]
+    fn can_turn_a_rombus_into_a_square() {
+        let a = Vec2D::new(1.64,1.06);
+        let b = Vec2D::new(6.2,1.9);
+        let c = Vec2D::new(8.72,-0.82);
+
+        // this is the tolerable error for this test
+        let epsilon = 0.004;
+
+        let t1 = rombus_to_rectangle(a, b, c);
+        assert!(dbg!(t1.apply(a).distance(Vec2D::new(0.0, 0.0))) < epsilon);
+        assert!(dbg!(t1.apply(b).distance(Vec2D::new(4.64, 0.0))) < epsilon);
+        assert!(dbg!(t1.apply(c).distance(Vec2D::new(4.64, 3.13))) < epsilon);
+    }
 }
