@@ -14,12 +14,14 @@ use self::builder::polygon::PolygonBuilder;
 use self::builder::center_and_radius_circle::CenterAndRadiusCircle;
 use self::builder::rectangle::AxisAlignedRectangleBuilder;
 use self::builder::three_point_circle::CircleThroughThreePointsBuilder;
+use self::builder::grid::Grid;
+use self::builder::free_grid::FreeGrid;
 
 /// Shapes handle input from the user, and they're responsible of notifying when
 /// they're finished, for example in the case of a polygon
 #[derive(Debug)]
 pub enum ShapeFinished {
-    Yes(Box<dyn ShapeStored>),
+    Yes(Vec<Box<dyn ShapeStored>>),
     No,
     Cancelled,
 }
@@ -39,6 +41,8 @@ pub enum ShapeTool {
     CircleByCenterAndPoint,
     CircleThroughThreePoints,
     ThreePointEllipse,
+    Grid,
+    FreeGrid,
 }
 
 impl ShapeTool {
@@ -50,11 +54,13 @@ impl ShapeTool {
             ShapeTool::CircleByCenterAndPoint => Box::new(CenterAndRadiusCircle::start(initial, style)),
             ShapeTool::CircleThroughThreePoints => Box::new(CircleThroughThreePointsBuilder::start(initial, style)),
             ShapeTool::ThreePointEllipse => Box::new(FociAndPointEllipse::start(initial, style)),
+            ShapeTool::Grid => Box::new(Grid::start(initial, style)),
+            ShapeTool::FreeGrid => Box::new(FreeGrid::start(initial, style)),
         }
     }
 }
 
-pub trait ShapeBuilder: std::fmt::Debug {
+pub trait ShapeBuilder: fmt::Debug {
     /// Must handle new coordinates given to this shape. If this method is
     /// called it means that the shape is being modified (thus this is the most
     /// recently added shape
